@@ -24,13 +24,13 @@ fi
 if  [[ $DISPLAY ]] ; then
 	dpkg-reconfigure -fgnome tzdata
 	dpkg-reconfigure -fgnome locales
-	dpkg-reconfigure -fgnome keyboard-configuration
+	dpkg-reconfigure -plow -fgnome keyboard-configuration
 else
 	echo -e "\n\tSet time zone and locales.\n"
 	sleep 2
 	dpkg-reconfigure tzdata
 	dpkg-reconfigure locales
-	dpkg-reconfigure keyboard-configuration
+	dpkg-reconfigure -plow keyboard-configuration
 fi
 
 
